game_qu.paths API documentation
Description: This module holds many path classes. A path is defined by some function of time that moves an object along the designated path.

# Module `game_qu.paths`

This module holds many path classes. A path is defined by some function of time that moves an object along the designated path.

Expand source code

    """This module holds many path classes. A path is defined by some function of time that moves an object along the designated path."""

## Sub-modules

`game_qu.paths.action_followable_path`
`game_qu.paths.followable_path`
`game_qu.paths.physics_followable_path`
`game_qu.paths.piecewise_followable_path`
`game_qu.paths.velocity_followable_path`